<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="he">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>נקה הכל</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>More</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NotifyCenter</name>
    <message>
        <source>No recent notifications</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>מרכז התראות</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>נקה הכל</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>More</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>הסר ממקובץ התראות</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>תETHER למקובץ התראות</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>הגדרות התראות</translation>
    </message>
</context>
<context>
    <name>NotifyViewDelegate</name>
    <message>
        <source>Clean All</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>JUST_NOW</translation>
    </message>
</context>
</TS>